<?php
/**
 * Helpers.
 *
 * @package cheshalo
 */

use XTS\Config;

if ( ! defined( 'CHESHALO_THEME_DIR' ) ) {
	exit( 'No direct script access allowed' );
}

if ( ! function_exists( 'cheshalo_get_current_page_builder' ) ) {
	/**
	 * Get current page builder.
	 *
	 * @since 6.1.0
	 */
	function cheshalo_get_current_page_builder() {
		$builder                = 'wpb';
		$theme_settings_builder = cheshalo_get_opt( 'page_builder' );

		if ( did_action( 'elementor/loaded' ) && ( 'auto' === $theme_settings_builder || 'elementor' === $theme_settings_builder ) ) {
			$builder = 'elementor';
		}

		if ( defined( 'WPB_VC_VERSION' ) && ( 'auto' === $theme_settings_builder || 'wpb' === $theme_settings_builder ) ) {
			$builder = 'wpb';
		}

		return $builder;
	}
}

if ( ! function_exists( 'cheshalo_is_blog_design_new' ) ) {
	/**
	 * Is blog design new.
	 *
	 * @since 6.1.0
	 *
	 * @param string $design Design.
	 */
	function cheshalo_is_blog_design_new( $design ) {
		$old = array(
			'default',
			'default-alt',
			'small-images',
			'chess',
			'masonry',
			'mask',
		);

		return ! in_array( $design, $old, true );
	}
}

if ( ! function_exists( 'cheshalo_get_element_template' ) ) {
	/**
	 * Loads a template part into a template.
	 *
	 * @since 6.1.0
	 *
	 * @param string $element_name  Template name.
	 * @param array  $args          Arguments.
	 * @param string $template_name Module name.
	 */
	function cheshalo_get_element_template( $element_name, $args, $template_name ) {
		if ( ! empty( $args ) && is_array( $args ) ) {
			extract( $args ); // phpcs:ignore
		}

		include CHESHALO_THEMEROOT . '/inc/template-tags/elements/' . $element_name . '/' . $template_name;
	}
}

if ( ! function_exists( 'cheshalo_get_old_classes' ) ) {
	/**
	 * Get old classes.
	 *
	 * @since 6.0.0
	 *
	 * @param string $classes Classes.
	 *
	 * @return string
	 */
	function cheshalo_get_old_classes( $classes ) {
		if ( ! cheshalo_get_opt( 'old_elements_classes', true ) ) {
			$classes = '';
		}

		return esc_html( $classes );
	}
}

if ( ! function_exists( 'cheshalo_get_headers_array' ) ) {
	/**
	 * Get custom header array created with header builder
	 *
	 * @since 1.0.0
	 *
	 * @param boolean $options Is function called in theme options.
	 *
	 * @return array
	 */
	function cheshalo_get_headers_array( $options = false ) {
		if ( $options ) {
			$list = get_option( 'whb_saved_headers' );
		} else {
			$list = whb_get_builder()->list->get_all();
		}

		$output = array();

		foreach ( $list as $key => $header ) {
			$output[ $key ] = array(
				'name'  => $header['name'],
				'value' => $key,
			);
		}

		return $output;
	}
}

if ( ! function_exists( 'cheshalo_get_current_url' ) ) {
	/**
	 * Get current url.
	 *
	 * @since 1.0.0
	 *
	 * @return string
	 */
	function cheshalo_get_current_url() {
		global $wp;

		return home_url( $wp->request );
	}
}

if ( ! function_exists( 'cheshalo_get_document_title' ) ) {
	/**
	 * Returns document title for the current page.
	 *
	 * @since 1.0.0
	 *
	 * @return string
	 */
	function cheshalo_get_document_title() {
		$title = wp_get_document_title();

		$post_meta = get_post_meta( cheshalo_get_the_ID(), '_yoast_wpseo_title', true );
		if ( property_exists( get_queried_object(), 'term_id' ) && function_exists( 'YoastSEO' ) ) {
			$taxonomy_helper = YoastSEO()->helpers->taxonomy;
			$meta            = $taxonomy_helper->get_term_meta( get_queried_object() );

			if ( isset( $meta['wpseo_title'] ) && $meta['wpseo_title'] ) {
				$title = wpseo_replace_vars( $meta['wpseo_title'], get_queried_object() );
			}
		} elseif ( $post_meta && function_exists( 'wpseo_replace_vars' ) ) {
			$title = wpseo_replace_vars( $post_meta, get_post( cheshalo_get_the_ID() ) );
		}

		return $title;
	}
}

if ( ! function_exists( 'cheshalo_get_new_size_classes' ) ) {
	/**
	 * Get new size classes.
	 *
	 * @param mixed $element Element.
	 * @param mixed $old_key Old key.
	 * @param mixed $selector Selector.
	 *
	 * @return string
	 */
	function cheshalo_get_new_size_classes( $element, $old_key, $selector ) {
		$array = array(
			'banner'       => array(
				'small'       => array(
					'subtitle' => 'xs',
					'title'    => 's',
				),
				'default'     => array(
					'subtitle' => 'xs',
					'title'    => 'l',
					'content'  => 'xs',
				),
				'large'       => array(
					'subtitle' => 's',
					'title'    => 'xl',
					'content'  => 'm',
				),
				'extra-large' => array(
					'subtitle' => 'm',
					'title'    => 'xxl',
				),
				'medium'      => array(
					'content' => 's',
				),
			),
			'infobox'      => array(
				'small'       => array(
					'subtitle' => 'xs',
					'title'    => 's',
				),
				'default'     => array(
					'subtitle' => 'xs',
					'title'    => 'm',
				),
				'large'       => array(
					'subtitle' => 's',
					'title'    => 'xl',
				),
				'extra-large' => array(
					'subtitle' => 'm',
					'title'    => 'xxl',
				),
			),
			'title'        => array(
				'small'       => array(
					'subtitle'    => 'xs',
					'title'       => 'm',
					'after_title' => 'xs',
				),
				'default'     => array(
					'subtitle'    => 'xs',
					'title'       => 'l',
					'after_title' => 'xs',
				),
				'medium'      => array(
					'subtitle'    => 'xs',
					'title'       => 'xl',
					'after_title' => 's',
				),
				'large'       => array(
					'subtitle'    => 'xs',
					'title'       => 'xxl',
					'after_title' => 's',
				),
				'extra-large' => array(
					'subtitle'    => 'm',
					'title'       => 'xxxl',
					'after_title' => 's',
				),
			),
			'text'         => array(
				'small'       => array(
					'title' => 'm',
				),
				'default'     => array(
					'title' => 'l',
				),
				'medium'      => array(
					'title' => 'xl',
				),
				'large'       => array(
					'title' => 'xxl',
				),
				'extra-large' => array(
					'title' => 'xxxl',
				),
			),
			'list'         => array(
				'default'     => array(
					'text' => 'xs',
				),
				'medium'      => array(
					'text' => 's',
				),
				'large'       => array(
					'text' => 'm',
				),
				'extra-large' => array(
					'text' => 'l',
				),
			),
			'testimonials' => array(
				'small'  => array(
					'text' => 'xs',
				),
				'medium' => array(
					'text' => 's',
				),
				'large'  => array(
					'text' => 'm',
				),
			),
		);

		return isset( $array[ $element ][ $old_key ][ $selector ] ) ? 'wd-fontsize-' . $array[ $element ][ $old_key ][ $selector ] : '';
	}
}

if ( ! function_exists( 'array_key_first' ) ) {
	function array_key_first( array $arr ) {
		foreach ( $arr as $key => $unused ) {
			return $key;
		}
		return null;
	}
}

if ( ! function_exists( 'cheshalo_is_elementor_full_width' ) ) {
	/**
	 * Check if Elementor full width.
	 *
	 * @param bool $negative_gap_ignore Is ignore negative gap option.
	 *
	 * @return boolean
	 */
	function cheshalo_is_elementor_full_width( $negative_gap_ignore = false ) {
		$page_template = get_post_meta( cheshalo_get_the_ID(), '_wp_page_template', true );

		if ( cheshalo_is_elementor_pro_installed() ) {
			$manager = \ElementorPro\Plugin::instance()->modules_manager->get_modules( 'theme-builder' )->get_conditions_manager();

			if ( $manager->get_documents_for_location( 'single' ) || $manager->get_documents_for_location( 'archive' ) ) {
				$page_template = 'elementor_header_footer';
			}
		}

		if ( $negative_gap_ignore ) {
			return 'elementor_header_footer' === $page_template;
		}

		return 'elementor_header_footer' === $page_template && 'enabled' !== cheshalo_get_opt( 'negative_gap', 'enabled' );
	}
}

if ( ! function_exists( 'cheshalo_is_elementor_pro_installed' ) ) {
	/**
	 * Check if Elementor PRO is activated
	 *
	 * @since 1.0.0
	 * @return boolean
	 */
	function cheshalo_is_elementor_pro_installed() {
		return defined( 'ELEMENTOR_PRO_VERSION' );
	}
}

if ( ! function_exists( 'cheshalo_vc_build_link' ) ) {
	function cheshalo_vc_build_link( $value ) {
		return cheshalo_vc_parse_multi_attribute(
			$value,
			array(
				'url'    => '',
				'title'  => '',
				'target' => '',
				'rel'    => '',
			)
		);
	}
}

if ( ! function_exists( 'cheshalo_vc_parse_multi_attribute' ) ) {
	function cheshalo_vc_parse_multi_attribute( $value, $default = array() ) {
		$result       = $default;
		$params_pairs = explode( '|', $value );
		if ( ! empty( $params_pairs ) ) {
			foreach ( $params_pairs as $pair ) {
				$param = preg_split( '/\:/', $pair );
				if ( ! empty( $param[0] ) && isset( $param[1] ) ) {
					$result[ $param[0] ] = rawurldecode( $param[1] );
				}
			}
		}

		return $result;
	}
}
if ( ! function_exists( 'cheshalo_get_size_guides_array' ) ) {
	function cheshalo_get_size_guides_array( $style = 'default' ) {
		if ( 'default' === $style ) {
			$output = array(
				esc_html__( 'Select', 'cheshalo' ) => '',
			);
		} elseif ( 'elementor' === $style ) {
			$output = array(
				'0' => esc_html__( 'Select', 'cheshalo' ),
			);
		}

		$posts = get_posts(
			array(
				'posts_per_page' => 200,
				'post_type'      => 'cheshalo_size_guide',
			)
		);

		foreach ( $posts as $post ) {
			if ( 'default' === $style ) {
				$output[ $post->post_title ] = $post->ID;
			} elseif ( 'elementor' === $style ) {
				$output[ $post->ID ] = $post->post_title;
			}
		}

		return $output;
	}
}

if ( ! function_exists( 'cheshalo_is_elementor_installed' ) ) {
	/**
	 * Check if Elementor is activated
	 *
	 * @since 1.0.0
	 * @return boolean
	 */
	function cheshalo_is_elementor_installed() {
		return did_action( 'elementor/loaded' ) && 'elementor' === cheshalo_get_current_page_builder();
	}
}
// **********************************************************************//
// Remove https
// **********************************************************************//

if ( ! function_exists( 'cheshalo_remove_https' ) ) {
	function cheshalo_remove_https( $link ) {
		return preg_replace( '#^https?:#', '', $link );
	}
}

// **********************************************************************//
// ! If page needs header
// **********************************************************************//

if ( ! function_exists( 'cheshalo_needs_header' ) ) {
	function cheshalo_needs_header() {
		return ( ! cheshalo_maintenance_page() && ! is_singular( 'cheshalo_slide' ) && ! is_singular( 'cms_block' ) );
	}
}

// **********************************************************************//
// ! If page needs footer
// **********************************************************************//

if ( ! function_exists( 'cheshalo_needs_footer' ) ) {
	function cheshalo_needs_footer() {
		return ( ! cheshalo_maintenance_page() && ! is_singular( 'cheshalo_slide' ) && ! is_singular( 'cms_block' ) );
	}
}


// **********************************************************************//
// ! Conditional tags
// **********************************************************************//

if ( ! function_exists( 'cheshalo_is_shop_archive' ) ) {
	function cheshalo_is_shop_archive() {
		return ( cheshalo_woocommerce_installed() && ( is_shop() || is_product_category() || is_product_tag() || is_singular( 'product' ) || cheshalo_is_product_attribute_archive() ) );
	}
}

if ( ! function_exists( 'cheshalo_is_blog_archive' ) ) {
	function cheshalo_is_blog_archive() {
		return ( is_home() || is_search() || is_tag() || is_category() || is_date() || is_author() );
	}
}

if ( ! function_exists( 'cheshalo_is_portfolio_archive' ) ) {
	function cheshalo_is_portfolio_archive() {
		return ( is_post_type_archive( 'portfolio' ) || is_tax( 'project-cat' ) );
	}
}

// **********************************************************************//
// ! Is maintenance page
// **********************************************************************//

if ( ! function_exists( 'cheshalo_maintenance_page' ) ) {
	function cheshalo_maintenance_page() {

		$pages_ids = cheshalo_pages_ids_from_template( 'maintenance' );

		if ( ! empty( $pages_ids ) && is_page( $pages_ids ) ) {
			return true;
		}

		return false;
	}
}

// **********************************************************************//
// ! Get config file
// **********************************************************************//

if ( ! function_exists( 'cheshalo_get_config' ) ) {
	function cheshalo_get_config( $name ) {
		return Config::get_instance()->get_config( $name );
	}
}


// **********************************************************************//
// ! Text to one-line string
// **********************************************************************//

if ( ! function_exists( 'cheshalo_text2line' ) ) {
	function cheshalo_text2line( $str ) {
		return trim( preg_replace( "/('|\"|\r?\n)/", '', $str ) );
	}
}


// **********************************************************************//
// ! Get page ID by it's template name
// **********************************************************************//
if ( ! function_exists( 'cheshalo_tpl2id' ) ) {
	function cheshalo_tpl2id( $tpl = '' ) {
		$pages = get_pages(
			array(
				'meta_key'   => '_wp_page_template',
				'meta_value' => $tpl,
			)
		);
		foreach ( $pages as $page ) {
			return $page->ID;
		}
	}
}


// **********************************************************************//
// ! Function print array within a pre tags
// **********************************************************************//
if ( ! function_exists( 'ar' ) ) {
	function ar( $array ) {

		echo '<pre>';
			print_r( $array );
		echo '</pre>';

	}
}


// **********************************************************************//
// ! Get protocol (http or https)
// **********************************************************************//
if ( ! function_exists( 'cheshalo_http' ) ) {
	function cheshalo_http() {
		if ( ! is_ssl() ) {
			return 'http';
		} else {
			return 'https';
		}
	}
}

// **********************************************************************//
// Cheshalo get theme info
// **********************************************************************//
if ( ! function_exists( 'cheshalo_get_theme_info' ) ) {
	function cheshalo_get_theme_info( $parameter ) {
		$theme_info = wp_get_theme();
		if ( is_child_theme() && is_object( $theme_info->parent() ) ) {
			$theme_info = wp_get_theme( $theme_info->parent()->template );
		}
		return $theme_info->get( $parameter );
	}
}

// **********************************************************************//
// Is share button enable
// **********************************************************************//
if ( ! function_exists( 'cheshalo_is_social_link_enable' ) ) {
	function cheshalo_is_social_link_enable( $type ) {
		$result = false;
		if ( $type == 'share' && ( cheshalo_get_opt( 'share_fb' ) || cheshalo_get_opt( 'share_twitter' ) || cheshalo_get_opt( 'share_linkedin' ) || cheshalo_get_opt( 'share_pinterest' ) || cheshalo_get_opt( 'share_ok' ) || cheshalo_get_opt( 'share_whatsapp' ) || cheshalo_get_opt( 'share_email' ) || cheshalo_get_opt( 'share_vk' ) || cheshalo_get_opt( 'share_tg' ) || cheshalo_get_opt( 'share_viber' ) ) ) {
			$result = true;
		}

		if ( $type == 'follow' && ( cheshalo_get_opt( 'fb_link' ) || cheshalo_get_opt( 'twitter_link' ) || cheshalo_get_opt( 'google_link' ) || cheshalo_get_opt( 'isntagram_link' ) || cheshalo_get_opt( 'pinterest_link' ) || cheshalo_get_opt( 'youtube_link' ) || cheshalo_get_opt( 'tumblr_link' ) || cheshalo_get_opt( 'linkedin_link' ) || cheshalo_get_opt( 'vimeo_link' ) || cheshalo_get_opt( 'flickr_link' ) || cheshalo_get_opt( 'github_link' ) || cheshalo_get_opt( 'dribbble_link' ) || cheshalo_get_opt( 'behance_link' ) || cheshalo_get_opt( 'soundcloud_link' ) || cheshalo_get_opt( 'spotify_link' ) || cheshalo_get_opt( 'ok_link' ) || cheshalo_get_opt( 'whatsapp_link' ) || cheshalo_get_opt( 'vk_link' ) || cheshalo_get_opt( 'snapchat_link' ) || cheshalo_get_opt( 'tg_link' ) || cheshalo_get_opt( 'tiktok_link' ) || cheshalo_get_opt( 'social_email' ) ) ) {
			$result = true;
		}

		return $result;
	}
}

// **********************************************************************//
// Is compare iframe
// **********************************************************************//
if ( ! function_exists( 'cheshalo_is_compare_iframe' ) ) {
	function cheshalo_is_compare_iframe() {
		return wp_script_is( 'jquery-fixedheadertable', 'enqueued' );
	}
}

// **********************************************************************//
// Is SVG image
// **********************************************************************//
if ( ! function_exists( 'cheshalo_is_svg' ) ) {
	function cheshalo_is_svg( $src ) {
		return substr( $src, -3, 3 ) == 'svg';
	}
}

// **********************************************************************//
// Get explode size
// **********************************************************************//
if ( ! function_exists( 'cheshalo_get_explode_size' ) ) {
	function cheshalo_get_explode_size( $img_size, $default_size ) {
		$sizes = explode( 'x', $img_size );
		if ( count( $sizes ) < 2 ) {
			$sizes[0] = $sizes[1] = $default_size;
		}
		return $sizes;
	}
}

// **********************************************************************//
// Check is theme is activated with a purchase code
// **********************************************************************//

if ( ! function_exists( 'cheshalo_is_license_activated' ) ) {
	function cheshalo_is_license_activated() {
		return get_option( 'cheshalo_is_activated', false );
	}
}

/**
 * ------------------------------------------------------------------------------------------------
 * Is shop on front page
 * ------------------------------------------------------------------------------------------------
 */
if ( ! function_exists( 'cheshalo_is_shop_on_front' ) ) {
	function cheshalo_is_shop_on_front() {
		return function_exists( 'wc_get_page_id' ) && 'page' === get_option( 'show_on_front' ) && wc_get_page_id( 'shop' ) == get_option( 'page_on_front' );
	}
}

if ( ! function_exists( 'cheshalo_get_allowed_html' ) ) {
	/**
	 * Return allowed html tags
	 *
	 * @since 1.0.0
	 *
	 * @return array
	 */
	function cheshalo_get_allowed_html() {
		return apply_filters(
			'cheshalo_allowed_html',
			array(
				'br'     => array(),
				'i'      => array(),
				'b'      => array(),
				'u'      => array(),
				'em'     => array(),
				'del'    => array(),
				'a'      => array(
					'href'   => true,
					'class'  => true,
					'target' => true,
					'title'  => true,
					'rel'    => true,
				),
				'strong' => array(),
				'span'   => array(
					'style' => true,
					'class' => true,
				),
			)
		);
	}
}


if ( ! function_exists( 'cheshalo_clean' ) ) {
	/**
	 * Clean variables using sanitize_text_field. Arrays are cleaned recursively.
	 * Non-scalar values are ignored.
	 *
	 * @param string|array $var Data to sanitize.
	 * @return string|array
	 */
	function cheshalo_clean( $var ) {
		if ( is_array( $var ) ) {
			return array_map( 'cheshalo_clean', $var );
		} else {
			return is_scalar( $var ) ? sanitize_text_field( $var ) : $var;
		}
	}
}
